package com.chinaitop.depot.storage.controller;


import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.feign.FeignBusinessService;
import com.chinaitop.depot.storage.model.*;
import com.chinaitop.depot.storage.model.StorageQualitycheckExample.Criteria;
import com.chinaitop.depot.storage.service.StorageQualitycheckService;
import com.chinaitop.depot.storage.service.StorageQualitycheckSonService;
import com.chinaitop.depot.storage.utils.DataSynchronization;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import net.sf.json.JSONObject;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * Created by product on 2017/10/11.
 */
@RestController
@RequestMapping(value = {"/qualitycheck"})
@Api(value= "StorageQualitycheckController", description = "质量管理控制类")
public class StorageQualitycheckController {
    @Resource
    private StorageQualitycheckService storageQualitycheckService;
    //远程调用
    @Resource
    private FeignBusinessService businessFileService;
    @Resource
    private StorageQualitycheckSonService qualitycheckSonService;

    /**
     * 封仓管理中查询出未封仓的质量管理信息，已经封仓的不要展示
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "qualitycheck", value = "实体类", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query"),
            @ApiImplicitParam(name = "quality", value = "储粮性质", paramType = "query"),
            @ApiImplicitParam(name = "subType", value = "粮食品种", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
            @ApiImplicitParam(name = "flagType", value = "验收结果", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize,
                                                  StorageQualitycheck qualitycheck, String checktype, String checkResult,
                                                  String quality, Integer subType, String searchStartDate, String searchEndDate, Integer orgId, String flagType) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            qualityCheck.setType(checktype);
        }
        if (StringUtils.isNotBlank(quality)){
            HashMap hashMap = JSON.parseObject(quality, HashMap.class);
            String ax = String.valueOf(hashMap.get("id"));
            qualityCheck.setQuality(ax);
        }
        if (subType!= null){
            qualityCheck.setSubType(subType);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            qualityCheck.setSearchStartDate(searchStartDate);
            qualityCheck.setSearchEndDate(searchEndDate);
        }

        // 仓房id.
        if (qualitycheck.getHouseId() != null) {
            qualityCheck.setHouseId(qualitycheck.getHouseId());

        }
        // 货位id.
        if (qualitycheck.getWarehouseId() != null) {
            qualityCheck.setWarehouseId(qualitycheck.getWarehouseId());
        }
        // 粮库id.
        if (orgId!= null) {
            qualityCheck.setOrgId(orgId);
        }
        
        // 明细品种.
        if (qualitycheck.getSubTypeDetailed() != null) {
            qualityCheck.setSubTypeDetailed(qualitycheck.getSubTypeDetailed());
        }
        
        // 等级.
        if (qualitycheck.getLevel() != null) {
            qualityCheck.setLevel(qualitycheck.getLevel());
        }

        //检验结果（0：合格 , 1 :不合格）
        if (StringUtils.isNotBlank(checkResult)) {
            qualityCheck.setCheckResult(checkResult);
        }

        //验收结果
        if (flagType != null) {
            qualityCheck.setFlagType(Integer.valueOf(flagType));
        }

        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        //qualityCheck.setSealStatus("0");
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitychecklist(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        if(pageInfo.getList()!=null){
            pageInfo.setStartRow(pageInfo.getStartRow());
            pageInfo.setEndRow(pageInfo.getEndRow());
        }
        return pageInfo;
    }
    
    /**
     * 获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位).
     * @param qualitycheck
     * @return
     */
    @RequestMapping(value = "/getHouseOrWareList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)", notes = "获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheck", value = "质量管理对象", paramType = "query")
    })
    public List<StorageQualitycheck> getHouseIdList(StorageQualitycheck qualitycheck) {
        List<StorageQualitycheck> list = storageQualitycheckService.getHouseOrWareList(qualitycheck);
        return list;
    }
    
    /**
     * 获取第三方检验的质量标准字符串(手动拼写)
     * @param id
     * @return
     */
    @RequestMapping(value = "/getQualityStandardStr",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取第三方检验的质量标准字符串(手动拼写)", notes = "获取第三方检验的质量标准字符串(手动拼写)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "form"),
    })
    public Map<String, Object> getQualityStandardStr(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id == null) {
            modelMap.put("status", "error");
            modelMap.put("msg", "id为空，查询质量标准失败！");
        } else {
            String qualityStandardStr = storageQualitycheckService.getQualityStandardStr(id);
            modelMap.put("status", "success");
            modelMap.put("qualityStandard", qualityStandardStr);
        }

        return modelMap;
    }
    
    

    /**
     * 新增和修改的数据进行保存
     * @param qualitycheckJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheckJson", value = "质量基础信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name="fileIds", value="文件数据", paramType="form"),
            @ApiImplicitParam(name = "qualityOneJson", value = "质量检测信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "qualityJson", value = "质量检测信息JSON数据对象", paramType = "form")
    })
    public Map<String, Object> save(String qualitycheckJson,String qualityOneJson,String qualityJson, String fileIds) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageQualitycheck qualitycheck = null;
        List<StorageQualitycheckSon> qualitycheckone = null;
        List<StorageQualitycheckSon> quality = null;
        try {
            qualitycheck = (StorageQualitycheck)mapper.readValue(qualitycheckJson, StorageQualitycheck.class);
            //默认0:未封仓   1:已封仓
            qualitycheck.setSealStatus("0");
            qualitycheck.setHistoryStatus(0);//0:最新数据   1:历史数据
            Integer qualityCheckId = storageQualitycheckService.save(qualitycheck);
            //关联保存日常检查和第三方检测的检测信息 如果为空则是对初检 验收等操作
            if(StringUtils.isNoneBlank(qualityOneJson)){
                qualitycheckone = mapper.readValue(qualityOneJson,  new TypeReference<List<StorageQualitycheckSon>>(){});
                for (int i = 0; i < qualitycheckone.size(); i++) {
                    qualitycheckone.get(i).setQualitycheckId(qualityCheckId);
                    storageQualitycheckService.saveOne(qualitycheckone.get(i));
                }
            }
            if(StringUtils.isNoneBlank(qualityJson)){
                quality = mapper.readValue(qualityJson,  new TypeReference<List<StorageQualitycheckSon>>(){});
                for (int i = 0; i < quality.size(); i++) {
                    quality.get(i).setQualitycheckId(qualitycheck.getId());
                    if (quality.get(i).getEnumid().equals("2783")||quality.get(i).getEnumid().equals("2791")||quality.get(i).getEnumid().equals("2799")){
                        qualitycheck.setWater(quality.get(i).getSetValue());//主表水分-用于储粮卡查看页面上的粮情质检记录
                    }else if(quality.get(i).getEnumid().equals("2797")||quality.get(i).getEnumid().equals("2807")||quality.get(i).getEnumid().equals("2789")){
                        qualitycheck.setEatScore(quality.get(i).getSetValue());//品尝分
                    }else if (quality.get(i).getEnumid().equals("2790")){
                        qualitycheck.setGlutenWaterCount(quality.get(i).getSetValue());//面筋吸水量
                    }else if (quality.get(i).getEnumid().equals("6996")||quality.get(i).getEnumid().equals("2798")||quality.get(i).getEnumid().equals("2808")){
                        qualitycheck.setFatIndex(quality.get(i).getSetValue());//脂肪酸值
                    }
                    quality.get(i).setNumbering(Integer.valueOf(quality.get(i).getEnumid()));
                    storageQualitycheckService.saveOne(quality.get(i));
                    storageQualitycheckService.save(qualitycheck);
                }
            }
            // 修改fileIds对应附件的bid为当前质检的id.
            businessFileService.updateFile(fileIds, qualitycheck.getId(),"qualitycheck");
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载质量检查数据", notes = "根据id加载质量检查数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public Map<String, Object> loadDataById(Integer id){
        Map<String, Object> qualitycheck=storageQualitycheckService.loadDataById(id);
        return qualitycheck;
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按ID删除质量检查信息", notes = "按ID删除质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        storageQualitycheckService.remove(id);

        //删除管理的数据
        StorageQualitycheckSonExample qualitycheckSonExample = new StorageQualitycheckSonExample();
        StorageQualitycheckSonExample.Criteria criteria = qualitycheckSonExample.createCriteria();
        if(id != null){
            criteria.andQualitycheckIdEqualTo(id);
        }
        qualitycheckSonService.removeSon(qualitycheckSonExample);
        retMap.put("msg","success");
        return retMap;
    }

    /**
     * 封仓管理中查询出所有仓已经封仓或者未封仓的质量管理信息
     * @param houseId
     * @param warehouseId
     * @return
     */
    @RequestMapping(value="/getFoodsealList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="封仓管理列表中查询出封仓或未封仓的质量管理信息", notes = "封仓管理列表中查询出封仓或未封仓的质量管理信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "quality", value = "储粮性质", paramType = "query"),
            @ApiImplicitParam(name = "subType", value = "粮食品种", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query"),
            @ApiImplicitParam(name = "sealStatus", value = "封仓状态", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")})
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize ,
                                                  String houseId, String warehouseId,Integer orgId,
                                                  String quality, Integer subType,String sealStatus,
                                                  String searchStartDate, String searchEndDate) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
        if(StringUtils.isNoneBlank(houseId)){
            qualityCheck.setHouseId(Integer.valueOf(houseId));

        }
        if(StringUtils.isNoneBlank(warehouseId)){
            qualityCheck.setWarehouseId(Integer.valueOf(warehouseId));
        }
        // 粮库id.
        if (orgId!= null) {
            qualityCheck.setOrgId(orgId);
        }
        qualityCheck.setType("1");///查找验收质量管理的信息

        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        if (StringUtils.isNotBlank(quality)){
            HashMap hashMap = JSON.parseObject(quality, HashMap.class);
            String ax = String.valueOf(hashMap.get("id"));
            qualityCheck.setQuality(ax);
        }
        if (subType!= null){
            qualityCheck.setSubType(subType);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            qualityCheck.setSearchStartDate(searchStartDate);
            qualityCheck.setSearchEndDate(searchEndDate);
        }
        if(sealStatus != null && ParameterUtil.isnotnull(sealStatus)){
            qualityCheck.setSealStatus(sealStatus);
        }
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 根据仓号,货位号以及类型查找对应质量检查信息
     * @param houseId warehouseId
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应质量检查信息", notes = "根据仓号,货位号以及类型查找对应质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "sealStatus", value = "封仓类型", paramType = "query")
    })
    public StorageQualitycheck findByStoreWarehouse(Integer houseId, Integer warehouseId, String type,String sealStatus) {
    	StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageQualitycheck qualitycheck = null;
        try {
            if (houseId != null && !"".equals(houseId)) {
                qualityCheckExample.setHouseId(houseId);

            }
            if(warehouseId != null && !"".equals(warehouseId)){
                qualityCheckExample.setWarehouseId(warehouseId);
            }
            if(StringUtils.isNotBlank(type)){
                qualityCheckExample.setType(type);//传入查找的质量类型
            }

            if(StringUtils.isNotBlank(sealStatus)){
                qualityCheckExample.setSealStatus(sealStatus);//传入查找的质量类型
            }
            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheckExample);
            if (null != list && list.size() > 0) {
            	qualitycheck = list.get(0);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return qualitycheck;
    }

    /**
     * 根据仓号,货位号以及类型查找对应封仓信息
     * @param houseId warehouseId
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouseData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应信息", notes = "根据仓号,货位号以及类型查找对应信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "检查id", paramType = "query")
    })
    public StorageFoodbasicinfo findByStoreWarehouseData(Integer houseId, Integer warehouseId, String type , Integer id) {
        StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        try {
            if (houseId != null && !"".equals(houseId)) {
                qualityCheckExample.setHouseId(houseId);
            }
            if(warehouseId != null && !"".equals(warehouseId)){
                qualityCheckExample.setWarehouseId(warehouseId);
            }
            if(StringUtils.isNotBlank(type)){
                qualityCheckExample.setType(type);//传入查找的质量类型
            }

            if (id != null && !"".equals(id)) {
                qualityCheckExample.setId(id);
            }

            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
            qualityCheckExample.setSealStatus("0");

            //查看business_store_ware_detail中价格是否有
            List<StorageQualitycheck> businessList = storageQualitycheckService.queryByQualitycheckusiness(qualityCheckExample);
            if(null != businessList && businessList.size() > 0){
                qualityCheckExample.setNotice(1);
            }

            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheckData(qualityCheckExample);
            if (null != list && list.size() > 0) {
                foodbasicinfo.setHeight(list.get(0).getHeight());
                foodbasicinfo.setWidth(list.get(0).getWidth());
                foodbasicinfo.setLength(list.get(0).getLength());
                foodbasicinfo.setDisperseCapacity(list.get(0).getDisperseCapacity());
                foodbasicinfo.setKeepMethod(list.get(0).getKeepMethod());
                foodbasicinfo.setPrice(list.get(0).getPrice());
                foodbasicinfo.setWareHouseName(list.get(0).getWareHouseName());
                foodbasicinfo.setStorehouseName(list.get(0).getStorehouseName());
                foodbasicinfo.setStorageLocation(list.get(0).getDepotName());
                foodbasicinfo.setPlaceOfOrigin(String.valueOf(list.get(0).getLocation()));//产地
                foodbasicinfo.setSubType(list.get(0).getSubType());//粮食品种
                foodbasicinfo.setNumber(Double.valueOf(list.get(0).getNumber()));//数量
                foodbasicinfo.setQuality(list.get(0).getQuality());//数量
                foodbasicinfo.setGrowYear(list.get(0).getHarvestTime());//收货年度
                foodbasicinfo.setLevel(String.valueOf(list.get(0).getLevel()));//d等级
                foodbasicinfo.setInputYear(list.get(0).getInputTime());//ruca入仓时间
                foodbasicinfo.setKeeperNames(list.get(0).getKeeper());//b保管员
                //保管单位-当前登录人的组织

            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return foodbasicinfo;
    }

    /**
     * 查询第三方检查
     * @param  foodbasicinfoId
     * @return getThirdCheckList
     */
    @RequestMapping(value="/getThirdCheckList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询获得质量检查列表", notes = "查询获得质量检查列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public PageInfo<StorageQualitycheck> getThirdCheckList(Integer pageNum, Integer pageSize , Integer houseId, Integer warehouseId,
                                                           Integer foodbasicinfoId) {
        StorageQualitycheck qualityCheck = new StorageQualitycheck();

        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }
        if(houseId != null){
            qualityCheck.setHouseId(houseId);
        }
        if(warehouseId != null){
            qualityCheck.setWarehouseId(warehouseId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.getThirdCheckList(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录(该记录包含当前仓房的验收信息和选择的第三方检验信息)
     * @param houseId
     * @param warehouseId
     * @param foodbasicinfoId
     * @return
     */
    @RequestMapping(value = "/getQualitycheckListByFoodbasicinfoCheck",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录", notes = "该记录包含当前仓房的验收信息和选择的第三方检验信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public List<StorageQualitycheck> getQualitycheckListByFoodbasicinfoCheck(Integer houseId, Integer warehouseId, Integer foodbasicinfoId){
        StorageQualitycheck qualityCheck = new StorageQualitycheck();
        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }
        if(houseId != null){
            qualityCheck.setHouseId(houseId);
        }
        if(warehouseId != null){
            qualityCheck.setWarehouseId(warehouseId);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.getQualitycheckListByFoodbasicinfoCheck(qualityCheck,foodbasicinfoId);

        return list;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    
    @RequestMapping(value = "/getStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据", notes = "获取第三方检查的不宜存的可用数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "粮库id", paramType = "query")

    })
    public List<Map<String,Object>> getStoreQualityList(Integer orgId){
        List<Map<String,Object>> listQuality=storageQualitycheckService.getStoreQualityList(orgId);
        return listQuality;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    @RequestMapping(value = "/getTrdStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据(集合格式)", notes = "获取第三方检查的不宜存的可用数据(集合格式)")
    public List<Map<String,Object>> getTrdStoreQualityList(){
    	List<Map<String,Object>> listQuality=storageQualitycheckService.getTrdStoreQualityList();    
        return listQuality;
    }
    
    
    @RequestMapping(value = "/setQualityCheckByHistoryStatus", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "根据仓房和货位名称更新当前质量管理为历史记录", notes = "根据仓房和货位名称更新当前质量管理为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
    })
    public Map<String, Object> setQualityCheckByHistoryStatus(Integer houseId, Integer warehouseId) {
        Map<String, Object> modelMap = new HashMap<>();
        if (ParameterUtil.isnotnull(houseId) &&ParameterUtil.isnotnull(warehouseId) ) {
            storageQualitycheckService.setQualityCheckByHistoryStatus(houseId,warehouseId);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 根据id查询质检信息
     * @param ZZid
     * @return
     */
    @RequestMapping(value="/getDataByZJId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value = "根据id查询质检信息", notes = "根据id查询质检信息,计划验收模块用到。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ZZid", value = "质检id", paramType = "query")
    })
    public Map<String,Object> getDataByZJId(Integer id ,Integer ZZid) {
        Map<String,Object> map = new HashMap<String, Object>();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        paramMap.put("ZZid", ZZid);
        paramMap.put("id", id);
        List<StorageQualitycheck> list = storageQualitycheckService.getDataByZJId(paramMap);
        map.put("qualitycheck", list);
        return map;
    }
    
    
    
    /**
     * 根据仓房和货位获取第三方检查的数据
     * 分页获取
     */
    @RequestMapping(value = "/getListByhouseId",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据仓房和货位获取第三方检查的数据", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseIds", value = "仓房id(数组)", paramType = "query"),
            @ApiImplicitParam(name = "warehouseIds", value = "货位id(数组)", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> getListByhouseId(Integer pageNum, Integer pageSize,
            Integer[] houseIds, Integer[] warehouseIds , String checktype) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
    	List<List<StorageQualitycheck>> list = new ArrayList<List<StorageQualitycheck>>();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            qualityCheck.setType(checktype);
        }
        
        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        qualityCheck.setSealStatus("0");
        
        List<StorageQualitycheck> qualityCheckList =null;
        for (int i = 0; i < houseIds.length; i++) {
        	for (int j = 0; j < warehouseIds.length; j++) {
            	if(i==j){
            		Integer houseId = houseIds[i];
            		Integer warehouseId = warehouseIds[j];
            		 	//仓房id.
            	        if (qualityCheck.getHouseId() == null) {
            	            qualityCheck.setHouseId(houseId);

            	        }
            	        // 货位id.
            	        if (qualityCheck.getWarehouseId() == null) {
            	            qualityCheck.setWarehouseId(warehouseId);
            	        }
            	        if (pageNum!=null && pageSize!=null) {
            	            PageHelper.startPage(pageNum, pageSize);
            	        }
            	        
            	        qualityCheckList = storageQualitycheckService.queryByQualitycheck(qualityCheck);
            	}
    		}
		}
        
       
       
        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(qualityCheckList);
        return pageInfo;
    }

    @RequestMapping(value = "/getNewList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query"),
            @ApiImplicitParam(name = "historyStatus", value = "数据状态", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> newListPage(Integer pageNum, Integer pageSize, Integer houseId, Integer wareId,
                                                  String checkType, String checkResult, Integer historyStatus, Integer orgId) {
    	StorageQualitycheckExample example = new StorageQualitycheckExample();
    	Criteria criteria = example.createCriteria();

        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checkType)){
        	criteria.andTypeEqualTo(checkType);
        }
        // 仓房id.
        if (houseId != null) {
        	criteria.andHouseIdEqualTo(houseId);
        }
        // 货位id.
        if (wareId != null) {
        	criteria.andWarehouseIdEqualTo(wareId);
        }
        // 粮库id.
        if (orgId != null) {
        	criteria.andOrgIdEqualTo(orgId);
        }

        //检验结果（0：合格 , 1 :不合格）
        if (StringUtils.isNotBlank(checkResult)) {
        	criteria.andCheckResultEqualTo(checkResult);
        }
        //数据状态
        if (null != historyStatus) {
        	//0:最新数据  1:历史数据
        	criteria.andHistoryStatusEqualTo(historyStatus);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.findByCondition(example);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    //质检信息主表同步
    @RequestMapping("/qualityMainSynchronization")
    public void qualityMainSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityMain(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQualityMain(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQualityMain(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //质检信息明细同步
    @RequestMapping("/qualityInfoSynchronization")
    public void qualityInfoSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityInfo(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQuality(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQuality(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //粮食库存同步
    @RequestMapping("/foodStocksSynchronization")
    public void foodStocksSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> foodStocksList = storageQualitycheckService.getAllFoodStocks(paramMap);
        for(Map foodStocksMap:foodStocksList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String fcid = ObjectUtils.toString(map.get("fcid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(fcid.equals(ObjectUtils.toString(foodStocksMap.get("fcid"),""))) {
                    if(!refreshTime.equals(format.format(foodStocksMap.get("updatetime")))) {
                        DataSynchronization.updateFoodStocks(map, foodStocksMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertFoodStocks(foodStocksMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

}